NetworkArenaClient

Struct NetworkArenaClient 

pub struct NetworkArenaClient { /* private fields */ }

Implementations

Source

impl NetworkArenaClient

pub fn new(command: Vec<String>) -> Self

Create a new NetworkArenaClient

Arguments
  • command - Command to run the client
Returns
  • NetworkArenaClient - The new NetworkArenaClient
pub fn connect( &mut self, addr: String, port: u16, ) -> Result<(), NetworkArenaClientError>

Connect to the server

Arguments
  • addr - IP address of the server
  • port - Port of the server
Returns
  • Result<(), NetworkArenaClientError> - Ok if successful
pub fn get_stats(&self) -> (usize, usize, usize)

Get the statistics of the games played

Returns
  • (usize, usize, usize) - Number of wins, loses and draws
Note
  • stats are cumulative
  • stats are not reset after each call to connect
  • stats are reset after each call to new
pub fn get_pieces(&self) -> (usize, usize)

Get the number of pieces played in the games

Returns
  • (usize, usize) - Number of pieces played by player and opponent
Note
  • pieces are cumulative
  • pieces are not reset after each call to connect
  • pieces are reset after each call to new